Add missing relocation types.

Patch by Jack Carter and Reed Kotler at Mips. 


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@141936 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/Mips/MipsRelocations.h b/lib/Target/Mips/MipsRelocations.h
index 255daf0..18f1b2b 100644
--- a/lib/Target/Mips/MipsRelocations.h
+++ b/lib/Target/Mips/MipsRelocations.h
@@ -53,7 +53,9 @@
       reloc_mips_gottprel   = 22, // R_MIPS_TLS_GOTTPREL
       reloc_mips_tprel_hi   = 23, // R_MIPS_TLS_TPREL_HI16
       reloc_mips_tprel_lo   = 24, // R_MIPS_TLS_TPREL_LO16
-      reloc_mips_branch_pcrel = 25 // This should become R_MIPS_PC16
+      reloc_mips_branch_pcrel = 25, // This should become R_MIPS_PC16
+      reloc_mips_pcrel      =  26, // R_MIPS_PC16
+      reloc_mips_j_jal      =  27 // R_MIPS_26
     };
   }
 }